//------------------------------------------------------------
#include <VirtualWire.h> //Library für 433MHz-Datenübertragung
//------------------------------------------------------------

// Libraries für DS18B20 Temperatursensoren-------------------
#include <OneWire.h>        
#include <DallasTemperature.h>
//------------------------------------------------------------

#define ATTiny

// OneWire-Referenz ------------------------------------------
#ifdef ATTiny
 #define ONE_WIRE_BUS 0          //PIN 0 am ATTiny für DS18B20 Data
 #define transmit_pin 1          //Sender Data an PIN 1
#else
 #define ONE_WIRE_BUS 5          //PIN 5 am Arduino für DS18B20 Data
 #define transmit_pin 4          //Sender Data an PIN 4  
#endif 

OneWire oneWire(ONE_WIRE_BUS);

// DS18B20 initialisieren ------------------------------------
DallasTemperature sensors(&oneWire);

// Array für die Deviceadressen ------------------------------
DeviceAddress insideThermometer;
 
float sensorwert;  //ausgelesene Temperatur

//allg. Variable ---------------------------------------------

char msg[5]; //Sensor_id - Array für Temperaturwerte


void setup() {
  //DS18B20 initialisieren -----------------------------------
  sensors.getAddress(insideThermometer, 0); //Thermometer Maischen, Kochen etc.
  sensors.setResolution(insideThermometer, 12);  //Auflösung 12 BIT (allerdings keine höhere Genauigkeit (+-0,5K)
  // Initialisiren des Sendepins -----------------------------
  #ifdef ATTiny
   vw_set_ptt_inverted(true);
  #endif
  vw_set_tx_pin(transmit_pin);
  // Geschwindigkeit der Datenübertragung --------------------
  vw_setup(2000);   // Bits/sek

#ifndef ATTiny    
 Serial.begin(115200);  //Testausgabe Serial Monitor
#endif 
}

void loop()
{ 
  sensors.requestTemperatures(); // Temperatur holen
  sensorwert = sensors.getTempCByIndex(0);
  dtostrf(sensorwert, 5, 3, msg);  //float -> Array of Char konvert. - 5=Zeichenzahl, 4 ist Präzision;
  vw_send((uint8_t *)msg, 5); //Senden des Temperaturwertes
  vw_wait_tx(); // Warten bis die Nachricht gesendet wurde
  delay(100);
  #ifndef ATTiny
   Serial.println(msg);  //Ausgabe der Temperatur im Serial-Monitor
  #endif
}
